@@ -44,7 +44,7 @@ import org.roaringbitmap.RoaringBitmap
 
 import org.apache.celeborn.common.CelebornConf
 import org.apache.celeborn.common.CelebornConf.PORT_MAX_RETRY
-import org.apache.celeborn.common.exception.CelebornException
+import org.apache.celeborn.common.exception.{CelebornException, CelebornIOException}
 import org.apache.celeborn.common.internal.Logging
 import org.apache.celeborn.common.meta.{DiskStatus, WorkerInfo}
 import org.apache.celeborn.common.network.protocol.TransportMessage
@@ -52,6 +52,7 @@ import org.apache.celeborn.common.network.util.TransportConf
 import org.apache.celeborn.common.protocol.{PartitionLocation, PartitionSplitMode, PartitionType, TransportModuleConstants}
 import org.apache.celeborn.common.protocol.message.{ControlMessages, Message, StatusCode}
 import org.apache.celeborn.common.protocol.message.ControlMessages.WorkerResource
+import org.apache.celeborn.reflect.DynConstructors
 
 object Utils extends Logging {
 
@@ -571,6 +572,33 @@ object Utils extends Logging {
     // scalastyle:on classforname
   }
 
+  def instantiateMasterEndpointResolver[T](
+      className: String,
+      conf: CelebornConf,
+      isWorker: Boolean): T = {
+    try {
+      DynConstructors.builder().impl(className, classOf[CelebornConf], java.lang.Boolean.TYPE)
+        .build[T]()
+        .newInstance(conf, java.lang.Boolean.valueOf(isWorker))
+    } catch {
+      case e: Throwable =>
+        throw new CelebornException(s"Failed to instantiate masterEndpointResolver $className.", e)
+    }
+  }
+
+  def instantiateDynamicConfigStoreBackend[T](className: String, conf: CelebornConf): T = {
+    try {
+      DynConstructors.builder().impl(className, classOf[CelebornConf])
+        .build[T]()
+        .newInstance(conf)
+    } catch {
+      case e: Throwable =>
+        throw new CelebornException(
+          s"Failed to instantiate dynamic config store backend $className.",
+          e)
+    }
+  }
+
   def getCodeSourceLocation(clazz: Class[_]): String = {
     new File(clazz.getProtectionDomain.getCodeSource.getLocation.toURI).getPath
   }
@@ -817,14 +845,15 @@ object Utils extends Logging {
       threadName: String,
       inputStream: InputStream,
       processLine: String => Unit): Thread = {
-    val t = new Thread(threadName) {
-      override def run(): Unit = {
-        for (line <- Source.fromInputStream(inputStream).getLines()) {
-          processLine(line)
+    val t = ThreadUtils.newDaemonThread(
+      new Runnable {
+        override def run(): Unit = {
+          for (line <- Source.fromInputStream(inputStream).getLines()) {
+            processLine(line)
+          }
         }
-      }
-    }
-    t.setDaemon(true)
+      },
+      threadName)
     t.start()
     t
   }
@@ -1041,10 +1070,24 @@ object Utils extends Logging {
         StatusCode.WORKER_EXCLUDED
       case 28 =>
         StatusCode.WORKER_UNKNOWN
+      case 29 =>
+        StatusCode.COMMIT_FILE_EXCEPTION
       case 30 =>
         StatusCode.PUSH_DATA_SUCCESS_PRIMARY_CONGESTED
       case 31 =>
         StatusCode.PUSH_DATA_SUCCESS_REPLICA_CONGESTED
+      case 32 =>
+        StatusCode.PUSH_DATA_HANDSHAKE_FAIL_REPLICA
+      case 33 =>
+        StatusCode.PUSH_DATA_HANDSHAKE_FAIL_PRIMARY
+      case 34 =>
+        StatusCode.REGION_START_FAIL_REPLICA
+      case 35 =>
+        StatusCode.REGION_START_FAIL_PRIMARY
+      case 36 =>
+        StatusCode.REGION_FINISH_FAIL_REPLICA
+      case 37 =>
+        StatusCode.REGION_FINISH_FAIL_PRIMARY
       case 38 =>
         StatusCode.PUSH_DATA_CREATE_CONNECTION_FAIL_PRIMARY
       case 39 =>
@@ -1071,6 +1114,8 @@ object Utils extends Logging {
         StatusCode.COMMIT_FILES_MOCK_FAILURE
       case 50 =>
         StatusCode.PUSH_DATA_FAIL_NON_CRITICAL_CAUSE_REPLICA
+      case 51 =>
+        StatusCode.OPEN_STREAM_FAILED
       case _ =>
         null
     }
@@ -1240,4 +1285,16 @@ object Utils extends Logging {
         (key, value)
     }.asInstanceOf[Seq[(K, V)]]
   }
+
+  def isCriticalCauseForFetch(e: Exception) = {
+    val rpcTimeout =
+      e.isInstanceOf[IOException] && e.getCause != null && e.getCause.isInstanceOf[TimeoutException]
+    val connectException =
+      e.isInstanceOf[CelebornIOException] && e.getMessage != null && (e.getMessage.startsWith(
+        "Connecting to") || e.getMessage.startsWith("Failed to"))
+    val fetchChunkTimeout = e.isInstanceOf[
+      CelebornIOException] && e.getCause != null && e.getCause.isInstanceOf[IOException]
+    connectException || rpcTimeout || fetchChunkTimeout
+  }
+
 }
