@@ -319,7 +319,7 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
 
       registeredShuffle.forEach(
           shuffleKey -> {
-            String appId = shuffleKey.split("-")[0];
+            String appId = Utils.splitShuffleKey(shuffleKey)._1;
             if (!appHeartbeatTime.containsKey(appId)) {
               appHeartbeatTime.put(appId, System.currentTimeMillis());
             }
@@ -474,4 +474,8 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
   public void updateApplicationMeta(ApplicationMeta applicationMeta) {
     applicationMetas.putIfAbsent(applicationMeta.appId(), applicationMeta);
   }
+
+  public void removeApplicationMeta(String appId) {
+    applicationMetas.remove(appId);
+  }
 }
