@@ -41,15 +41,9 @@ case class MasterNode(
 
   def rpcEndpoint: String = rpcHost + ":" + rpcPort
 
-  def rpcIpEndpoint: String = rpcAddr.getAddress.getHostAddress + ":" + rpcPort
-
   def internalRpcEndpoint: String = rpcHost + ":" + internalRpcPort
 
-  def internalRpcIpEndpoint: String = rpcAddr.getAddress.getHostAddress + ":" + rpcPort
-
   lazy val ratisAddr = MasterNode.createSocketAddr(ratisHost, ratisPort)
-
-  lazy val rpcAddr = MasterNode.createSocketAddr(rpcHost, rpcPort)
 }
 
 object MasterNode extends Logging {
