@@ -18,17 +18,18 @@
 package org.apache.celeborn.service.deploy.worker;
 
 import org.apache.celeborn.common.protocol.PartitionLocation;
-import org.apache.celeborn.service.deploy.worker.storage.FileWriter;
+import org.apache.celeborn.service.deploy.worker.storage.PartitionDataWriter;
 
 public class WorkingPartition extends PartitionLocation {
-  private final transient FileWriter fileWriter;
+  private final transient PartitionDataWriter partitionDataWriter;
 
-  public WorkingPartition(PartitionLocation partitionLocation, FileWriter fileWriter) {
+  public WorkingPartition(
+      PartitionLocation partitionLocation, PartitionDataWriter partitionDataWriter) {
     super(partitionLocation);
-    this.fileWriter = fileWriter;
+    this.partitionDataWriter = partitionDataWriter;
   }
 
-  public FileWriter getFileWriter() {
-    return fileWriter;
+  public PartitionDataWriter getFileWriter() {
+    return partitionDataWriter;
   }
 }
